@@ -5,6 +5,8 @@ import os
 import pathlib
 from bmpm import functions
 from bmpm import util
+from bmpm.__version__ import version
+
 
 def main():
 #   Cli Arguments Setup
@@ -12,7 +14,8 @@ def main():
 
     parser = argparse.ArgumentParser(description=progDesc)
     subParser = parser.add_subparsers(description='Sub-Commands required to use the functions of BMPM', dest='subParserType')
-    parser.add_argument('fileIn', type=str, help="File to open and read data from.")
+    parser.add_argument('fileIn', type=str, help="File to open and read data from.", default=None)
+#    parser.add_argument('--version', '-v', dest='version', help='Displays the current version of BMPM being run.', required=False)
     parser.add_argument('--noCompression', '-nc', action='store_true', help='Add this if you would prefer the program to not compress the output file with yaz0.')
     parser.add_argument('--bigEndian', '-be', action='store_true', dest='endian', help='Outputs the files in a big endian format', required=False, default=False)
 
@@ -24,27 +27,31 @@ def main():
 
     remParser = subParser.add_parser('delete', help='Remove an actor or actors from the map file(s) based on either name or hashID')
     remParser.add_argument('ActorToDelete', help='The actor name or HashID you would like removed from the map file.')
+    remParser.add_argument('--fragment', '-f', dest='subStr', action='store_true', help='Whether or not the inputted search term is a prefix to search for or not.', required=False)
     remParser.add_argument('--type', '-t', metavar='value', dest='type', choices=['0', '1', 'hash', 'name'], help='Type of string that was inputted for actor removal(0 maps to hash and 1 to actor name, will default to actor name.)', required=False, default=1)
 
     convParser = subParser.add_parser('convert', help='Converts one actor to another based off of a template.')
     convParser.add_argument('--type', '-t', metavar='value', dest='type', choices=['0', '1', 'hash', 'name'], help='Type of string that was inputted for actor removal(0 maps to hash and 1 to actor name, will default to actor name.)', required=False, default=1)
+    convParser.add_argument('--fragment', '-f', dest='subStr', action='store_true', help='Whether or not the inputted search term is a prefix to search for or not.', required=False)
     convParser.add_argument('actorConvertFrom', help='The actor name or hashID you would like to be converted.')
     convParser.add_argument('actorConvertTo', type=str, help='Actor to convert to.')
 
+    endSwap = subParser.add_parser('swap', help='A function to detect and quickly convert the endianness of map files.')
+
     genParser = subParser.add_parser('genDB', help='Generate the database of actors necessary for using the replace actor function. Only needs to be run once.')
 
 
 #   Global Variables
     args = parser.parse_args()
-    print(args.endian)
-    fileToOpen = pathlib.Path(args.fileIn)
-    fileToOpen = fileToOpen
-    if fileToOpen.is_file():
-        fileObj = fileToOpen
-        fileName = str(fileObj).split('.')[0]
-        fileExt = ('.' + str(fileObj).split('.')[-1])
-    else:
-        print('Directory entered, beginning recursive processes.')
+    if (args.fileIn != None):
+        fileToOpen = pathlib.Path(args.fileIn)
+        fileToOpen = fileToOpen
+        if fileToOpen.is_file():
+            fileObj = fileToOpen
+            fileName = str(fileObj).split('.')[0]
+            fileExt = ('.' + str(fileObj).split('.')[-1])
+        else:
+            print('Directory entered, beginning recursive processes.')
 
 
     if (args.subParserType == 'edit'):
@@ -106,7 +113,18 @@ def main():
             functions.genActorDatabase(fileToOpen)
         else:
             print('Cancelling operation.')
-
+    
+#    elif(args.subParserType == 'version'):
+#        print(f"BMPM-{str(version)}")
+    elif(args.subParserType == 'swap'):
+            if fileToOpen.is_dir():
+                fileList = util.checkDir(fileToOpen)
+                for fileToOpen in fileList:
+                    fileName = str(fileToOpen).split('.')[0]
+                    fileExt = ('.' + str(fileToOpen).split('.')[-1])
+                    functions.swapEnd(fileToOpen, fileName, fileExt, args)
+            else:
+                functions.swapEnd(fileToOpen, fileName, fileExt, args)
     else:
         print(f'The option {str(args.subParserType)} could not be found.')
 
